Definitions of basic terms
==========================

.. glossary::

    DataTables
        A jQuery plugin to support advanced interaction controls to any HTML table. More at http://datatables.net/.

    jEditable
        A edit-in-place jQuery plugin. More at http://www.appelsiini.net/projects/jeditable.